autofs-5.0.8 - fix negative status being reset on map read

From: Ian Kent <raven@themaw.net>

The map entry status field, which holds the negative cache timeout,
gets reset on a map re-read.

If the negative map entry was added at the same time as the map
read and it was for an entry that was never in the map, the
status gets reset even though the entry is still a valid
negative entry.

Consequently lookups for non-existent map entries are never
seen as negative and the lookup always continues.
---
 CHANGELOG       |    1 +
 daemon/lookup.c |    3 ++-
 2 files changed, 3 insertions(+), 1 deletion(-)

diff --git a/CHANGELOG b/CHANGELOG
index 30bfed9..f9e14b1 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -17,6 +17,7 @@
 - extend fix for crash due to thread unsafe use of libldap.
 - fix deadlock in init_ldap_connection.
 - fix options compare.
+- fix negative status being reset on map read.
 
 17/10/2013 autofs-5.0.8
 =======================
diff --git a/daemon/lookup.c b/daemon/lookup.c
index 7fea942..fb6370c 100644
--- a/daemon/lookup.c
+++ b/daemon/lookup.c
@@ -1050,7 +1050,8 @@ void lookup_prune_one_cache(struct autofs_point *ap, struct mapent_cache *mc, ti
 			 * Reset time of last fail for valid map entries to
 			 * force entry update and subsequent mount retry.
 			 */
-			me->status = 0;
+			if (me->mapent)
+				me->status = 0;
 			me = cache_enumerate(mc, me);
 			continue;
 		}
